@@ -12,7 +12,7 @@ class Constants:
         self.__parameter_map[key] = value
 
     def get_value_by_key(self, key):
-        self.__parameter_map.get(key, None)
+        return self.__parameter_map.get(key, None)
 
 
 CONSTANTS_INSTANCE = Constants()
